# _Event

::: pyflp._event._Event

# ByteEvent

::: pyflp._event._ByteEvent

# _WordEvent

::: pyflp._event._WordEvent

# _DWordEvent

::: pyflp._event._DWordEvent

## _ColorEvent

::: pyflp._event._ColorEvent

# _TextEvent

::: pyflp._event._TextEvent

# _DataEvent

::: pyflp._event._DataEvent
